pub struct InactiveQueryCursor { /* private fields */ }Expand description
A query cursor that is not actively associated with a query
Implementations
Sourceimpl InactiveQueryCursor
impl InactiveQueryCursor
pub fn new(range: Range<u32>, limit: u32) -> Self
Sourcepub fn match_limit(&self) -> u32
pub fn match_limit(&self) -> u32
Return the maximum number of in-progress matches for this cursor.
Sourcepub fn set_match_limit(&mut self, limit: u32)
pub fn set_match_limit(&mut self, limit: u32)
Set the maximum number of in-progress matches for this cursor. The limit must be > 0 and <= 65536.
Sourcepub fn did_exceed_match_limit(&self) -> bool
pub fn did_exceed_match_limit(&self) -> bool
Check if, on its last execution, this cursor exceeded its maximum number of in-progress matches.
pub fn set_byte_range(&mut self, range: Range<u32>)
pub fn execute_query<'a, 'tree, I: IntoInput>( self, query: &'a Query, node: &Node<'tree>, input: I, ) -> QueryCursor<'a, 'tree, I::Input>