InputEdit

Struct InputEdit 

#[repr(C)]
pub struct InputEdit { pub start_byte: u32, pub old_end_byte: u32, pub new_end_byte: u32, pub start_point: Point, pub old_end_point: Point, pub new_end_point: Point, }

Fields

start_byte: u32old_end_byte: u32new_end_byte: u32start_point: Pointold_end_point: Pointnew_end_point: Point

Implementations

Source

impl InputEdit

pub fn offset(&self) -> i32

returns the offset between the old end of the edit and the new end of the edit. This offset needs to be added to every position that occurs after self.old_end_byte to may it to its old position

This function assumes that the the source-file is smaller than 2GiB