Parser

Struct Parser 

pub struct Parser { /* private fields */ }
A stateful object that this is used to produce a Tree based on some source code.

Implementations

Source

impl Parser

pub fn new() -> Parser

Create a new parser.

pub fn set_grammar( &mut self, grammar: Grammar, ) -> Result<(), IncompatibleGrammarError>

Set the language that the parser should use for parsing.

pub fn set_timeout(&mut self, duration: Duration)

pub fn set_included_ranges( &mut self, ranges: &[Range], ) -> Result<(), InvalidRangesError>

Set the ranges of text that the parser should include when parsing. By default, the parser will always include entire documents. This function allows you to parse only a portion of a document but still return a syntax tree whose ranges match up with the document as a whole. You can also pass multiple disjoint ranges.

ranges must be non-overlapping and sorted.

pub fn parse<I: Input>( &mut self, input: impl IntoInput<Input = I>, old_tree: Option<&Tree>, ) -> Option<Tree>