QueryMatch

Struct QueryMatch 

pub struct QueryMatch<'cursor, 'tree> { /* private fields */ }

Implementations

Source

impl<'tree> QueryMatch<'_, 'tree>

pub fn matched_nodes(&self) -> impl Iterator<Item = &MatchedNode<'tree>>

pub fn nodes_for_capture( &self, capture: Capture, ) -> impl Iterator<Item = &Node<'tree>>

pub fn matched_node(&self, i: MatchedNodeIdx) -> &MatchedNode<'tree>

pub const fn id(&self) -> u32

pub const fn pattern(&self) -> Pattern

pub fn remove(self)

removes this match from the cursor so that further captures from its cursor so that future captures that belong to this match are no longer returned by capture iterators